#
# spec file for package act
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Orville Q. Song <orville@anislet.dev>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         nketos
%global repo            act
%global provider_prefix %{provider}.%{provider_tld}/%{project}
%global import_path     %{provider_prefix}/%{repo}
Name:           act
Version:        0.2.34
Release:        bp155.2.7
Summary:        Run your GitHub Actions locally
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/nektos/act
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.16
Requires:       docker
%{go_nostrip}
%{go_provides}

%description
act helps you run your Github Actions locally.

%prep
%setup -q
%setup -q -a1 %{SOURCE1}
sed -i 's_var version = \"v0.2.27-dev\"_var version = "%{version}"_g' main.go

%build
%{goprep} .
mkdir -p vendor/%{provider_prefix}
ln -s . vendor/%{import_path}
%{gobuild} -ldflags "-s -w -X main.Version=v%{version}" .

%install
%{goinstall}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Wed Jan 11 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.34
- Spec file:
  Fix bsc#1207021 to report the correct version when calling "act --version"
  Wrong version is fixed with sed in act-0.2.34/main.go
  Reported upstream as GH://nektos/act#1555
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.34
- Update to version 0.2.34:
  * feat: interpolate the step names (#1422)
  * feat: GITHUB_STATE and GITHUB_OUTPUT file commands (#1391)
  * feat: Host environment (#1293)
  * feat: parse types of reusable workflows (#1414)
  * fix: handle subdirectors and exclusions (#1012) (#1446)
  * fix: keep path to event json file in composite actions (#1428)
  * fix: nil pointer access ( workflow_dispatch )
  * build(deps): bump megalinter/megalinter from 6.14.0 to 6.15.0 (#1475)
  * act -j -W example (#1471)
  * Fix shellcommand error on sh shell (#1464)
  * fix typo (#1456)
  * build(deps): bump github.com/creack/pty from 1.1.17 to 1.1.18 (#1447)
  * Remove dead code (#1425)
  * build(deps): bump github.com/moby/buildkit from 0.10.5 to 0.10.6 (#1437)
  * build(deps): bump golangci/golangci-lint-action from 3.3.0 to 3.3.1 (#1436)
  * Update number of approvers required from 3 to 2
  * build(deps): bump megalinter/megalinter from 6.13.0 to 6.14.0 (#1426)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.21 to 1.6.22 (#1427)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.33
- Update to version 0.2.33:
  * fix: ci is failing since 2022-10-17 (#1397)
  * fix: re-evaluate env for remote composite actions (#1385)
  * fix: interpolate action input defaults (#1376)
  * fix: support docker create arguments from container.options (#1022) (#1351)
  * fix: handle go closure iteration (#1374)
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#1420)
  * build(deps): bump github.com/docker/docker (#1418)
  * build(deps): bump github.com/docker/cli (#1419)
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#1404)
  * refactor: move from io/ioutil to io and os packages (#1417)
  * Add user level Docker socket to common paths (#1416)
  * build(deps): bump megalinter/megalinter from 6.12.0 to 6.13.0 (#1407)
  * build(deps): bump golangci/golangci-lint-action from 3.2.0 to 3.3.0 (#1408)
  * build(deps): bump github.com/docker/docker (#1403)
  * build(deps): bump github.com/docker/cli (#1405)
  * build(deps): bump github.com/moby/buildkit from 0.10.4 to 0.10.5 (#1406)
  * Fixes #1387 (#1388)
  * build(deps): bump megalinter/megalinter from 6.11.1 to 6.12.0 (#1395)
  * build(deps): bump github.com/docker/cli (#1393)
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#1394)
  * build(deps): bump github.com/docker/docker (#1392)
  * Mapping workflow_dispatch inputs into the Expression inputs context (#1363)
  * test: add test for networking setup in act (#1375)
  * build(deps): bump megalinter/megalinter from 6.11.0 to 6.11.1 (#1381)
  * build(deps): bump gotest.tools/v3 from 3.0.3 to 3.4.0 (#1379)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.20 to 1.6.21 (#1380)
  * build(deps): bump github.com/imdario/mergo from 0.3.12 to 0.3.13 (#1378)
  * Fix composite input handling (#1345)
  * build(deps): bump megalinter/megalinter from 5 to 6.11.0 (#1370)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.19 to 1.6.20 (#1371)
  * build(deps): bump github.com/opencontainers/selinux (#1372)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.32
- Update to version 0.2.32:
  * feat: pass current matrix information to job logger (#1364)
  * fix: show workflow info even if on.push is not defined (#1329) (#1335)
  * fix: restore the job logger setup after job cancelation (#1365)
  * fix: align github.ref to GitHub Action (#1362)
  * fix: crash on invalid docker credentials (#1348)
  * fix: missing defaults in nodejs pre (#1349)
  * fix: support expression for step's continue-on-error field (#900) (#1331)
  * fix: show workflow name when get error on yml parsing (#1133) (#1328)
  * build(deps): bump codecov/codecov-action from 3.1.0 to 3.1.1 (#1359)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.18 to 1.6.19 (#1360)
  * build(deps): bump actions/stale from 5 to 6 (#1357)
  * Arch best practice is to not run partial upgrades (#1355)
  * Improve hint for inserting secrets securely (#1354)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.17 to 1.6.18 (#1352)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.5 to 2.3.6 (#1341)
  * build(deps): bump github.com/docker/cli (#1340)
  * build(deps): bump github.com/docker/docker (#1339)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.31
- Update to version 0.2.31:
  * fix: CI is unstable due to new linting rules (#1292)
  * help output: use consistent terminology between -j & -l (#1326)
  * support runner.arch (#1290)
  * build(deps): bump github.com/moby/buildkit from 0.10.3 to 0.10.4 (#1322)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.16 to 1.6.17 (#1321)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to 0.0.16 (#1312)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.15 to 1.6.16 (#1311)
  * build(deps): bump github.com/go-ini/ini from 1.66.6 to 1.67.0 (#1305)
  * refactor: ignore already closed error (#1285)
* Wed Aug 10 2022 jayvdb@gmail.com
- Update to version 0.2.30:
  * fix: ensure all post steps are executed (#1286)
  * walk submodule path instead of dir name (#1282)
  * fix: add parent step id in composite action step id (#1268)
  * Made env interpolated instead of evaluated. (#1222)
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#1273)
  * Update README.md (#1260)
  * lint: add ReadHeaderTimeout (#1277)
  * fix: the number in the github event is of type number (#1252)
  * only perform chown operation for non root users (#1250)
  * fix: allow TimeoutMinutes to be expression in Jobs (#1247)
  * fix: use docker images from dockerhub (#1249)
  * Improve --eventpath example command (#1243)
  * Improve docs for events inputs (#1238)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.14 to 1.6.15 (#1239)
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0 (#1240)
* Sun Jul  3 2022 elimat@opensuse.org
- Update to version 0.2.29:
  * build(deps): bump github.com/rhysd/actionlint from 1.6.13 to 1.6.14 (#1234)
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#1233)
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.5 (#1232)
  * fix: checkout container path should always use `/` (#1226)
  * feat: add option to bypass GHE for actions checkout (#1162)
  * revert auto changelog generator
  * ignore release-notes.md to avoid dirty check in goreleaser
  * update to use PAT
  * setup git user
  * allow workflow_dispatch on tag-monthly
  * add monthly release
  * auto generate changelog (#1225)
  * update runc and containerd (#1224)
  * feat: non root user container (#1202)
  * fix: processing of strategy.matrix.include (#1200)
  * fix: localcheckout mock (#1198)
  * Added support for chunked uploads. (#1208)
  * fix: keep action inputs (#1215)
  * Improve logging (#1171)
  * fix: allow TimeoutMinutes to be expression (#1217)
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#1213)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.4 to 2.3.5 (#1214)
  * build(deps): bump github.com/docker/cli (#1211)
  * build(deps): bump github.com/docker/docker (#1212)
  * refactor: remove github.com/pkg/errors dependency (#1077)
  * fix: skip local actions pre step in any case (#1204)
  * pkg/runner: add support to replace GitHub's env (#1197)
  * fix: dryrun skip local actions + enable Tests (#1199)
  * fix: Remove volume with same name as the container again (#1203)
  * build(deps): bump github.com/go-ini/ini from 1.66.5 to 1.66.6 (#1201)
  * build(deps): bump github.com/go-ini/ini from 1.66.4 to 1.66.5 (#1189)
  * governance: fix bug report rendering (#1186)
  * update docs (#1180)
  * feat: handle context cancelation during docker exec (#1170)
  * implement pre and post steps (#1089)
  * fix: remove composite restrictions (#1128)
  * governance: new issue templates (#1048)
  * ci(choco): update chocolatey to 1.1.0 (#1164)
  * build(deps): bump goreleaser/goreleaser-action from 2 to 3 (#1179)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.12 to 1.6.13 (#1173)
  * feat: add ubuntu-22.04 (#1150)
  * feat/bug-report-extended (#1163)
  * build(deps): bump golangci/golangci-lint-action from 3.1.0 to 3.2.0 (#1169)
  * build(deps): bump github.com/docker/docker (#1167)
  * build(deps): bump github.com/docker/cli (#1168)
  * fix: panic if a step in a job is nil (#1145)
  * fix: return invalid step type (#1157)
  * Remove the correct Volume (#1148)
  * fix: panic while running DRYRUN with local actions (#1141)
  * refactor: remove composite action runcontext workaround (#1085)
  * build(deps): bump github.com/moby/buildkit from 0.10.2 to 0.10.3 (#1153)
  * build(deps): bump docker/setup-qemu-action from 1 to 2 (#1156)
  * build(deps): bump github.com/docker/docker (#1155)
  * build(deps): bump github.com/docker/cli (#1154)
  * feat: support `GITHUB_REF_NAME` & `GITHUB_REF_TYPE` (#1142)
  * build(deps): bump github.com/moby/buildkit from 0.10.1 to 0.10.2 (#1147)
  * fix: conclusion and outcome are no integers (#1136)
  * fix: do not error that much (#1137)
  * build(deps): bump codecov/codecov-action from 3.0.0 to 3.1.0 (#1139)
  * chore: fold integration test outputs (#1111)
  * Update README.md (#1121)
  * docs(README): remove go install (#1123)
  * ci: always grab latest go version (#1124)
  * tests: remove runTestJobFile (#1127)
  * use new paths from goreleaser (#1135)
  * README: add MacPorts badge (#1129)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.11 to 1.6.12 (#1126)
  * build(deps): bump codecov/codecov-action from 2.1.0 to 3.0.0 (#1118)
  * build(deps): bump github.com/moby/buildkit from 0.10.0 to 0.10.1 (#1116)
  * build(deps): bump actions/upload-artifact from 2 to 3 (#1119)
  * build(deps): bump actions/setup-go from 2 to 3 (#1120)
  * build(deps): bump actions/stale from 4 to 5 (#1117)
  * tests(runner): move arm64 test to own func (#1095)
  * build(deps): bump deps which dependabot doesn't want to (#1107)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.10 to 1.6.11 (#1106)
  * implement volume mount for container job (#1101)
  * feat: add option to specify git remote name (#1104)
  * Allow passed in env vars to supersede ones declared in the workflow (#1100)
  * fix: copy ignored tracked files (#1074)
  * build(deps): bump github.com/opencontainers/selinux (#1102)
  * fix: return error on reusable workflows (#1093)
  * deps: bump go.mod to go1.18 (#1088)
  * fix(editorconfig): correct braces (#1094)
  * ci: bump go to 1.18 (#1087)
  * fix: don't overwrite with empty cmd/entrypoint (#1076)
  * refactor: simplify action function signatures (#1083)
  * deps: remove shlex (#1086)
  * fix: set default version string (#1070)
  * build(deps): bump actions/cache from 2 to 3 (#1082)
  * build(deps): bump github.com/docker/docker (#1080)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.2 to 2.3.4 (#1079)
  * build(deps): bump github.com/docker/cli (#1081)
  * automatically merge PRs from dependabot (#1084)
  * deps: bump go-git (#1057)
  * feat: split job steps into its own files/structs (#1004)
  * feat: add bug-report flag (#1056)
  * Fix: panic: reflect: slice index out of range (#1066)
  * Fix: call of reflect.Value.Interface on zero Value (#1067)
  * Fix: tojson(null) == 'null' (#1068)
  * build(deps): bump github.com/docker/docker (#1062)
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1 (#1061)
  * feat: add flag to always run the checkout action (#1049)
  * Revert: Don't stop JobContainer on failure (#1041)
  * fix: remove unused TestContext (#1013)
  * feat: add step name to logger field (#1027)
  * fix: coerce booleans to numbers for comparison in exprparser (#1030)
  * feat: add json logger output (#1026)
  * build(deps): bump golangci/golangci-lint-action from 2 to 3.1.0 (#1019)
  * ci(stalebot): ignore feature requests (#1017)
  * build(deps): bump actions/checkout from 2 to 3 (#1028)
  * build(deps): bump github.com/spf13/cobra from 1.3.0 to 1.4.0 (#1040)
  * build(deps): bump github.com/docker/cli (#1038)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.9 to 1.6.10 (#1039)
  * build(deps): bump github.com/docker/distribution (#1037)
  * build(deps): bump github.com/moby/buildkit from 0.9.3 to 0.10.0 (#1036)
  * fix: trim whitespace from actrc (#1024)
  * fix: hide masked values in log files (#1011)
  * build(deps): bump github.com/spf13/cobra from 1.2.1 to 1.3.0 (#955)
  * Update link to 'filesystems' GitHub docs (#1016)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.8 to 1.6.9 (#1018)
  * feat: run jobs in parallel (#1003)
  * Expression evaluator fixes (#1009)
  * build(deps): bump github.com/go-ini/ini from 1.64.0 to 1.66.4 (#997)
  * fix: print line after password prompt (#1014)
  * refactor: default empty if: statement to if: success() in evaluator & remove `FixIfStatement()` (#990)
  * fix: deep evaluate matrix strategy (#964)
  * build(deps): bump github.com/docker/distribution (#994)
  * Added instructions to install on fedora using copr package (#993)
  * fix: always execute closeContainer() executor (#988)
  * refactor: extract setupAction into ActionReader (#986)
  * refactor: extract RunContext Executor in JobExecutor (#984)
  * docs: Expand the GITHUB_TOKEN section (#968)
  * ci(Mergify): configuration update (#972)
  * fix: docker cp of dangling symlink (#943) (#948)
  * Fix: regression run after failure (#971)
  * ci(Mergify): configuration update (#966)
  * build(deps): bump github.com/moby/buildkit from 0.9.2 to 0.9.3 (#958)
  * build(deps): bump github.com/docker/docker (#957)
  * build(deps): bump github.com/opencontainers/image-spec (#954)
  * build(deps): bump github.com/docker/cli (#956)
  * Test: env.ACT in if condition of the workflow (#965)
  * feat: add skipped status as step result (#950)
  * feat: try to read ref and sha from event payload if available (#889)
  * fix: set composite outputs on failure (#945)
  * Refactor expression evaluator to use parser from actionlint package (#908)
  * fix(goreleaser): add append mode for release notes (#962)
  * feat(goreleaser): format changelog, add prereleases (#942)
  * fix: update install.sh (#937)
  * refactor: export and move shared contexts into pkg/model (#931)
  * feat: add node16 support (#922)
  * Feature: uses in composite (#793)
  * lint(megalinter): disable markdown link check (#938)
  * ci: replace superlinter with megalinter (#923)
  * fix: rework setupShellCommand (#930)
  * fix: clarify --reuse and --rm flags (#929)
  * ci(Mergify): configuration update (#924)
  * fix: ::stop-commands:: should continue to print the lines (#920)
  * fix: continue jobs + steps after failure (#840)
  * Fix and test choco action (#911)
  * Docker auth (#891)
  * container credentials (#868)
  * Add more steps context support (#887)
  * feat: allow existing logger from context (#898)
  * feat: SELinux lables for --bind (#906)
  * ci(choco): fix chocolatey docker build (#903)
- Add go modules (vendor) suport in _service file
- run spec-cleaner
* Sun Dec  5 2021 Orville Q. Song <orville@anislet.dev>
- Update to version 0.2.25:
  * feat: add option for docker image rebuild (#878)
  * Don't interpolate joboutputs, before job is done (#894)
  * Fix regex for GITHUB_ENV parsing (#893)
  * Revert "feat: allow existing logger from context (#859)" (#890)
  * docs: add brew installation from HEAD (#886)
  * build(deps): bump github.com/go-ini/ini from 1.63.2 to 1.64.0 (#882)
  * fix: fromJSON should work with any JSON (#883)
  * fix: correctly unmarshal entrypoint (#876)
  * fix: use docker lib for image ref parsing (#877)
  * Fix github SSH regex for missing .git extension (#871)
* Sat Dec  4 2021 Orville Q. Song <orville@anislet.dev>
- Init act Package.
  Run your GitHub Actions locally. 🚀
  Current Release: v0.2.25
  Commit Hash: 8ad6c07083c7cd7f45ea9e0808e3297bf2370ab5
